# Qiskit Code Assistant Jupyterlab Demos

This directory contains example files to aid in demos of the extension

You can also see a video demo of v0.1.0 [hosted on Box](https://ibm.box.com/s/mc4bvwgf2x51ydkjbnkzngo9rzr75hxs)
